.. _random-numbers:

**************
Random numbers
**************

Most practical applications of |thejoker| involve generating enormous libraries
of prior pdf samples to operate on. Whenever large numbers of computer-generated
random numbers are needed, its important to be aware of subtleties of
pseudo-random generators.

TODO

